summaryrefslogtreecommitdiff
path: root/node/IncomingPacket.hpp
diff options
context:
space:
mode:
authorAdam Ierymenko <adam.ierymenko@gmail.com>2015-04-07 19:31:11 -0700
committerAdam Ierymenko <adam.ierymenko@gmail.com>2015-04-07 19:31:11 -0700
commit49f031ccb4d518e8a715777f5d848759bae0def8 (patch)
tree6f5d2fe9a753d36ac1da657142fc50645804466d /node/IncomingPacket.hpp
parent9e55f882d3ca5a5615c21ebaec0702aaaf436e2b (diff)
downloadinfinitytier-49f031ccb4d518e8a715777f5d848759bae0def8.tar.gz
infinitytier-49f031ccb4d518e8a715777f5d848759bae0def8.zip
Tons of refactoring, change to desperation algorithm to use max of core or link, porting over core loop code from old Node.cpp to new CAPI version, etc.
Diffstat (limited to 'node/IncomingPacket.hpp')
-rw-r--r--node/IncomingPacket.hpp9
1 files changed, 4 insertions, 5 deletions
diff --git a/node/IncomingPacket.hpp b/node/IncomingPacket.hpp
index ef25fbc4..bc727dee 100644
--- a/node/IncomingPacket.hpp
+++ b/node/IncomingPacket.hpp
@@ -70,15 +70,14 @@ public:
/**
* Create a new packet-in-decode
*
* @param b Source buffer with raw packet data
* @param remoteAddress Address from which packet came
* @param linkDesperation Link desperation for link over which packet was received
* @throws std::out_of_range Range error processing packet
*/
- template<unsigned int C2>
- IncomingPacket(const Buffer<C2> &b,const InetAddress &remoteAddress,unsigned int linkDesperation)
- throw(std::out_of_range) :
- Packet(b),
+ IncomingPacket(const void *data,unsigned int len,const InetAddress &remoteAddress,unsigned int linkDesperation) :
+ Packet(data,len),
_receiveTime(Utils::now()),
_remoteAddress(remoteAddress),
_linkDesperation(linkDesperation),
@@ -70,15 +70,14 @@ public:
* Create a new packet-in-decode
*
- * @param b Source buffer with raw packet data
+ * @param data Packet data
+ * @param len Packet length
* @param remoteAddress Address from which packet came
* @param linkDesperation Link desperation for link over which packet was received